@@ -1,4 +1,4 @@
-/* $Id: aggregate.c,v 1.11 2001/11/02 15:49:18 jabley Exp $
+/* $Id: aggregate.c,v 1.12 2002/03/06 16:55:38 jabley Exp $
  * 
  * Copyright (c) 2000-2001 by Metromedia Fiber Network Services, Inc.
  * 
@@ -89,7 +89,7 @@ int moanf(int fatal, char *fmt, ...)
 
 int my_inet_aton(const char *cp, struct in_addr *addr)
 {
-  in_addr_t val;
+  struct in_addr val;
   int n;
   char c;
   u_int parts[4];
@@ -106,11 +106,11 @@ int my_inet_aton(const char *cp, struct in_addr *addr)
     if (!isdigit(c))
       return (0);
 
-    val = 0;
+    val.s_addr = 0;
 
     for (;;) {
       if (isdigit(c)) {
-        val = (val * 10) + (c - '0');
+        val.s_addr = (val.s_addr * 10) + (c - '0');
         c = *++cp;
       } else
         break;
@@ -125,7 +125,7 @@ int my_inet_aton(const char *cp, struct in_addr *addr)
        */
       if (pp >= parts + 3)
         return (0);
-      *pp++ = val;
+      *pp++ = val.s_addr;
       c = *++cp;
     } else
       break;
@@ -145,27 +145,27 @@ int my_inet_aton(const char *cp, struct in_addr *addr)
       break;
 
     case 2:       /* a.b -- 8.24 bits */
-      if ((val > 0xffffff) || (parts[0] > 0xff))
+      if ((val.s_addr > 0xffffff) || (parts[0] > 0xff))
         return (0);
-      val |= parts[0] << 24;
+      val.s_addr |= parts[0] << 24;
       break;
 
     case 3:       /* a.b.c -- 8.8.16 bits */
-      if ((val > 0xffff) || (parts[0] > 0xff) || (parts[1] > 0xff))
+      if ((val.s_addr > 0xffff) || (parts[0] > 0xff) || (parts[1] > 0xff))
         return (0);
-      val |= (parts[0] << 24) | (parts[1] << 16);
+      val.s_addr |= (parts[0] << 24) | (parts[1] << 16);
       break;
 
     case 4:       /* a.b.c.d -- 8.8.8.8 bits */
-      if ((val > 0xff) || (parts[0] > 0xff) || (parts[1] > 0xff) || \
+      if ((val.s_addr > 0xff) || (parts[0] > 0xff) || (parts[1] > 0xff) || \
           (parts[2] > 0xff))
         return (0);
-      val |= (parts[0] << 24) | (parts[1] << 16) | (parts[2] << 8);
+      val.s_addr |= (parts[0] << 24) | (parts[1] << 16) | (parts[2] << 8);
       break;
   }
 
   if (addr)
-    addr->s_addr = htonl(val);
+    addr->s_addr = htonl(val.s_addr);
   return (1);
 }
 
